@@ -15,17 +15,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- * $Id: options.c,v 1.6 2005/12/22 13:23:11 hanke Exp $
+ * $Id: options.c,v 1.9 2006/07/11 16:12:26 hanke Exp $
  */
 
 /* NOTE: Be careful not to include options.h, we would
    get repetitive initializations warnings */
 
 #define PACKAGE "spd-say"
-#define VERSION "0.3"
+#define VERSION "0.4"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -55,7 +55,9 @@ options_print_help(char *argv[])
 	   "                                female3, child_male, child_female)\n"
 	   "-m, --punctuation-mode -     Set the punctuation mode (none, some, all) \n"
 	   "-s, --spelling         -     Spell the message\n"
+           "-x, --ssml             -     Set SSML mode on (default: off)\n"
            "\n"
+           "-e, --pipe-mode        -     Pipe from stdin to stdout plus Speech Dispatcher\n"
            "-P, --priority         -     Set priority of the message (important, message,\n"
            "                                text, notification, progress; default: text)\n"
            "-N, --application-name -     Set the application name used to estabilish\n"
@@ -87,7 +89,7 @@ void
 options_print_version()
 {
     printf("spd-say: "PACKAGE" "VERSION"\n");
-    printf("Copyright (C) 2002-2005 Brailcom, o.p.s.\n"
+    printf("Copyright (C) 2002-2006 Brailcom, o.p.s.\n"
            "spd-say comes with ABSOLUTELY NO WARRANTY.\n"
            "You may redistribute copies of spd-say\n"
            "under the terms of the GNU General Public License.\n"
@@ -156,9 +158,15 @@ options_parse(int argc, char *argv[])
 	case 's':
 	    spelling = 1;
 	    break;
+        case 'e':
+            pipe_mode = 1;
+            break;
 	case 'P':
 	    OPT_SET_STR(priority);
 	    break;
+        case 'x':
+            ssml_mode = 1;
+            break;
 	case 'N':
 	    OPT_SET_STR(application_name);
 	    break;
