@@ -1,24 +1,24 @@
 /*
  * module_utils.c - Module utilities
  *           Functions to help writing output modules for Speech Dispatcher
- * Copyright (C) 2003 Brailcom, o.p.s.
+ * Copyright (C) 2003,2006 Brailcom, o.p.s.
  *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * This is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License as published by the Free
+ * Software Foundation; either version 2.1, or (at your option) any later
+ * version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this package; see the file COPYING.  If not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
- * $Id: module_utils.c,v 1.39 2006/01/08 13:36:57 hanke Exp $
+ * $Id: module_utils.c,v 1.43 2006/07/11 16:12:27 hanke Exp $
  */
 
 #include "fdsetconv.h"
@@ -57,7 +57,6 @@ void
 xfree(void *data)
 {
     if (data != NULL) free(data);
-    data = NULL;
 }
 
 char*
@@ -619,7 +618,7 @@ module_sigblockusr(sigset_t *some_signals)
     sigaddset(some_signals, SIGUSR1);
     ret = sigprocmask(SIG_SETMASK, some_signals, NULL);
     if (ret != 0)
-	DBG("flite: Can't block signal set, expect problems when terminating!\n");
+	DBG("Can't block signal set, expect problems when terminating!\n");
     
 }
 
@@ -633,9 +632,9 @@ set_speaking_thread_parameters()
     if (ret == 0){
 	ret = pthread_sigmask(SIG_BLOCK,&all_signals,NULL);
         if (ret != 0)
-            DBG("flite: Can't set signal set, expect problems when terminating!\n");
+            DBG("Can't set signal set, expect problems when terminating!\n");
     }else{
-        DBG("flite: Can't fill signal set, expect problems when terminating!\n");
+        DBG("Can't fill signal set, expect problems when terminating!\n");
     }
 
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
