@@ -3,22 +3,22 @@
  *           Functions to help writing output modules for Speech Dispatcher
  * Copyright (C) 2003, 2004 Brailcom, o.p.s.
  *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * This is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License as published by the Free
+ * Software Foundation; either version 2.1, or (at your option) any later
+ * version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this package; see the file COPYING.  If not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
- * $Id: module_utils.h,v 1.9 2005/12/07 08:28:30 hanke Exp $
+ * $Id: module_utils.h,v 1.13 2006/07/11 16:12:27 hanke Exp $
  */
 
 #include <semaphore.h>
@@ -271,7 +271,7 @@ configoption_t * add_config_option(configoption_t *options, int *num_config_opti
     { \
         T ## name *new_item; \
         char* new_key; \
-        new_item = (new_item*) malloc(sizeof(new_item)); \
+        new_item = (T ## name *) malloc(sizeof(T ## name)); \
         if (cmd->data.list[0] == NULL) return NULL; \
         new_item->arg1 = strdup(cmd->data.list[0]); \
         new_key = strdup(cmd->data.list[0]); \
