@@ -2,7 +2,7 @@
 /*
  * module.c - Output modules for Speech Dispatcher
  *
- * Copyright (C) 2001, 2002, 2003 Brailcom, o.p.s.
+ * Copyright (C) 2001, 2002, 2003, 2006 Brailcom, o.p.s.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -16,10 +16,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- * $Id: module.c,v 1.28 2006/01/08 13:36:57 hanke Exp $
+ * $Id: module.c,v 1.31 2006/07/20 15:32:48 hanke Exp $
  */
 
 #define _GNU_SOURCE
@@ -77,7 +77,8 @@ load_output_module(char* mod_name, char* mod_prog, char* mod_cfgfile, char* mod_
 
     /* Open the file for child stderr (logging) redirection */
     if (module->debugfilename != NULL){
-	module->stderr_redirect = open(module->debugfilename, O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
+	module->stderr_redirect = open(module->debugfilename,
+				       O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
 	if (module->stderr_redirect == -1)
 	    MSG(1,"ERROR: Openning debug file for %s failed: (error=%d) %s", module->name,
 		module->stderr_redirect, strerror(errno));    
