@@ -22,4 +22,8 @@ char* deescape_dot(char *otext);
 /* Function for parsing the input from clients */
 char* get_param(const char *buf, const int n, const int bytes, const int lower_case);
 
+/* Other internal functions */
+char* parse_general_event(const char *buf, const int bytes, const int fd, EMessageType type);
+int spd_utf8_read_char(char* pointer, char* character);
+
 #endif
