@@ -16,10 +16,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- * $Id: speechd.h,v 1.54 2006/01/08 13:36:58 hanke Exp $
+ * $Id: speechd.h,v 1.56 2006/07/11 16:12:28 hanke Exp $
  */
 
 #ifndef SPEECHDH
@@ -108,6 +108,7 @@ typedef struct{
 struct{
     int port, port_set;
     int log_level, log_level_set;
+    char *pid_file;
     int max_history_messages;	/* Maximum of messages in history before they expire */
 }SpeechdOptions;
 
@@ -129,9 +130,6 @@ pthread_mutex_t socket_com_mutex;
 key_t speaking_sem_key;
 int speaking_sem_id;
 
-/* PID file name */
-char *speechd_pid_file;
-
 /* Table of all configured (and succesfully loaded) output modules */
 GHashTable *output_modules;	
 /* Table of settings for each active client (=each active socket)*/
